"""
The scene processing part of the toolbox defines methodes
to transform an image into a place code in the sense
of Basten and Mallot (2010).

The scene is either

* a 4d numpy array, used when the image is a equirectangular \
projection, i.e. a panoramic image.
* a 3d numpy array, used when the viewing direction can not \
be mapped/projected on a regular image (e.g. insect eye).

We thus define the following for a scene:

image based scene (IBS)
  A classical image. Each pixel is viewed in a direction
  (elevation,azimuth) in a regular manner.
  In that case the scene is a 4d numpy array
  [elevation-index,azimuth-index,channel-index,1].

Omatidium based scene (OBS)
  In an ommatidia based scene, the viewing direction
  do not need to be regularally spaced.
  In that case the scene is a 3d numpy array
  [ommatidia-index, channel-index,1].

By extension a place-code is either image based or ommatidium based.
The number of dimension of an ib-place-code is always 4, and of an
ob-place-code always 3.

image based place-code (IBPC)
    A place code derived from IBS. Each pixel is viewed in a direction
    (elevation,azimuth) in a regular manner.
    In that case the scene is a 4d numpy array
    [elevation-index,azimuth-index,channel-index,component-index].

Omatidium based place-code (OBPC)
    A place code derived from OBS, the viewing direction
    do not need to be regularally spaced.
    In that case the scene is a 3d numpy array
    [ommatidia-index, channel-index,component-index].


Abusing the terminology of a place-code, a scene can be a place-code.
Therefore ibs and obs have 4 and 3 dimension, respectively.
"""
